@@ -71,7 +71,7 @@ class InfluxDBDriver(drivers.Driver):
             ),
             path=["/opt/influxdb"])
 
-        self.addCleanup(self._kill, c.pid)
+        self.addCleanup(self._kill, c)
 
         self._exec(["influx",
                     "-port", str(self.port),
